@@ -5,4 +5,4 @@ from gto.config import CONFIG
 from gto.index import RepoIndexManager
 from gto.registry import GitRegistry
 
-__all__ = ["api", "CONFIG", "RepoIndexManager", "GitRegistry"]
+__all__ = ["api", "CONFIG", "RepoIndexManager", "GitRegistry", "__version__"]
