@@ -1,4 +1,5 @@
 # pylint: disable=no-self-use, no-self-argument, inconsistent-return-statements, invalid-name, import-outside-toplevel
+import pathlib
 import re
 from pathlib import Path
 from typing import Any, Dict, List, Optional
@@ -22,13 +23,14 @@ CONFIG_FILE_NAME = ".gto"
 
 
 def check_name_is_valid(name):
-    return bool(re.match(r"[a-zA-Z0-9-/]*$", name))
+    return bool(re.match(r"[a-z][a-z0-9-/]*[a-z0-9]$", name))
 
 
 def assert_name_is_valid(name):
     if not check_name_is_valid(name):
         raise ValidationError(
             f"Invalid value '{name}'. Only alphanumeric characters, '-', '/' are allowed."
+            "Value must be of len >= 2, must with a letter and end with a letter or a number."
         )
 
 
@@ -42,8 +44,8 @@ class EnrichmentConfig(BaseModel):
 
 class NoFileConfig(BaseSettings):
     INDEX: str = "artifacts.yaml"
-    TYPE_ALLOWED: List[str] = []
-    STAGE_ALLOWED: List[str] = []
+    TYPES: Optional[List[str]]
+    STAGES: Optional[List[str]]
     LOG_LEVEL: str = "INFO"
     DEBUG: bool = False
     ENRICHMENTS: List[EnrichmentConfig] = []
@@ -56,13 +58,13 @@ class NoFileConfig(BaseSettings):
 
     def assert_type(self, name):
         assert_name_is_valid(name)
-        if self.TYPE_ALLOWED and name not in self.TYPE_ALLOWED:
-            raise UnknownType(name, self.TYPE_ALLOWED)
+        if self.TYPES is not None and name not in self.TYPES:
+            raise UnknownType(name, self.TYPES)
 
     def assert_stage(self, name):
         assert_name_is_valid(name)
-        if self.stages and name not in self.stages:
-            raise UnknownStage(name, self.stages)
+        if self.STAGES is not None and name not in self.STAGES:
+            raise UnknownStage(name, self.STAGES)
 
     @property
     def enrichments(self) -> Dict[str, Enrichment]:
@@ -71,22 +73,24 @@ class NoFileConfig(BaseSettings):
             return {**find_enrichments(), **res}
         return res
 
-    @property
-    def stages(self) -> List[str]:
-        return self.STAGE_ALLOWED
-
-    @validator("TYPE_ALLOWED")
+    @validator("TYPES")
     def types_are_valid(cls, v):
-        for name in v:
-            assert_name_is_valid(name)
+        if v:
+            for name in v:
+                assert_name_is_valid(name)
         return v
 
-    @validator("STAGE_ALLOWED")
+    @validator("STAGES")
     def stages_are_valid(cls, v):
-        for name in v:
-            assert_name_is_valid(name)
+        if v:
+            for name in v:
+                assert_name_is_valid(name)
         return v
 
+    def check_index_exist(self, repo: str):
+        index = pathlib.Path(repo) / pathlib.Path(self.INDEX)
+        return index.exists() and index.is_file()
+
 
 def _set_location_init_source(init_source: InitSettingsSource):
     def inner(settings: "RegistryConfig"):
@@ -135,6 +139,10 @@ class RegistryConfig(NoFileConfig):
                 file_secret_settings,
             )
 
+    def config_file_exists(self):
+        config = pathlib.Path(self.CONFIG_FILE_NAME)
+        return config.exists() and config.is_file()
+
 
 def read_registry_config(config_file_name):
     try:
